@@ -14,25 +14,33 @@ using namespace GrantleeTheme;
 class GrantleeTheme::EnginePrivate
 {
 public:
-    EnginePrivate()
-    {
-    }
+    EnginePrivate() = default;
 
-    ~EnginePrivate()
-    {
-    }
+    ~EnginePrivate() = default;
 
     QWeakPointer<GrantleeKi18nLocalizer> localizer;
 };
 
 Engine::Engine(QObject *parent)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     : Grantlee::Engine(parent)
+#else
+    : KTextTemplate::Engine(parent)
+#endif
     , d(new GrantleeTheme::EnginePrivate)
 {
     addPluginPath(QStringLiteral(GRANTLEE_PLUGIN_INSTALL_DIR));
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     addDefaultLibrary(QStringLiteral("grantlee_i18ntags"));
+#else
+    addDefaultLibrary(QStringLiteral("ktexttemplate_i18ntags"));
+#endif
     addDefaultLibrary(QStringLiteral("kde_grantlee_plugin"));
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     addDefaultLibrary(QStringLiteral("grantlee_scriptabletags"));
+#else
+    addDefaultLibrary(QStringLiteral("ktexttemplate_scriptabletags"));
+#endif
     setSmartTrimEnabled(true);
 }
 
