@@ -7,7 +7,11 @@
 #pragma once
 
 #include <QSharedPointer>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <grantlee/engine.h>
+#else
+#include <KTextTemplate/Engine>
+#endif
 
 #include "grantleetheme_export.h"
 
@@ -18,7 +22,11 @@ class EnginePrivate;
 /**
  * @brief The Engine class
  */
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 class GRANTLEETHEME_EXPORT Engine : public Grantlee::Engine
+#else
+class GRANTLEETHEME_EXPORT Engine : public KTextTemplate::Engine
+#endif
 {
     Q_OBJECT
 
@@ -32,4 +40,3 @@ private:
     std::unique_ptr<EnginePrivate> const d;
 };
 }
-
